==> jc-1.4.0.tar.gz: soot/jimple/parser/BodyExtractorWalker.h <==
// public class soot.jimple.parser.BodyExtractorWalker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 72cded5f00a3b1f0 soot_jimple_parser_BodyExtractorWalker
// @dep_class b8af2571138d5c8f soot_jimple_parser_Walker
// @dep_class b43a9165b67db951 soot_jimple_parser_analysis_AnalysisAdapter
// @dep_class 49cf7a14fc836e70 soot_jimple_parser_analysis_DepthFirstAdapter

// header file dependencies
// @dep_header soot_jimple_parser_Walker

#include "soot/jimple/parser/Walker.h"

#ifndef _JC_soot_jimple_parser_BodyExtractorWalker_H_
#define _JC_soot_jimple_parser_BodyExtractorWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootResolver$object;
struct _jc_soot_jimple_parser_node_AFieldMember$object;
struct _jc_soot_jimple_parser_node_AFile$object;
struct _jc_soot_jimple_parser_node_AMethodMember$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_refs	_jc_soot_jimple_parser_BodyExtractorWalker$sub_refs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs	_jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$refs	_jc_soot_jimple_parser_BodyExtractorWalker$refs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$nonrefs	_jc_soot_jimple_parser_BodyExtractorWalker$nonrefs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$object	_jc_soot_jimple_parser_BodyExtractorWalker$object;

typedef const struct _jc_soot_jimple_parser_BodyExtractorWalker$vmethods	_jc_soot_jimple_parser_BodyExtractorWalker$vmethods;
typedef const struct _jc_soot_jimple_parser_BodyExtractorWalker$vtable	_jc_soot_jimple_parser_BodyExtractorWalker$vtable;
typedef const struct _jc_soot_jimple_parser_BodyExtractorWalker$vtype	_jc_soot_jimple_parser_BodyExtractorWalker$vtype;

// Constructors
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$_init$9a25abd79642d432(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_SootClass$object *, struct _jc_soot_SootResolver$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$caseAFile$b6916389b57c776a(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$outAFieldMember$280c058d1a940a2c(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFieldMember$object *);
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$outAFile$453969294ea1f0d8(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$outAMethodMember$0fbbcd28a24c2ab7(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$caseAFile$b6916389b57c776a;
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$outAFieldMember$280c058d1a940a2c;
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$outAFile$453969294ea1f0d8;
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$outAMethodMember$0fbbcd28a24c2ab7;

// Virtual methods structure
struct _jc_soot_jimple_parser_BodyExtractorWalker$vmethods {
	void	(*caseAFile$b6916389b57c776a)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
	void	(*outAFieldMember$280c058d1a940a2c)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFieldMember$object *);
	void	(*outAFile$453969294ea1f0d8)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
	void	(*outAMethodMember$0fbbcd28a24c2ab7)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *);
};

// Vtable
struct _jc_soot_jimple_parser_BodyExtractorWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_analysis_AnalysisAdapter$vmethods	soot_jimple_parser_analysis_AnalysisAdapter;
	_jc_soot_jimple_parser_analysis_DepthFirstAdapter$vmethods	soot_jimple_parser_analysis_DepthFirstAdapter;
	_jc_soot_jimple_parser_Walker$vmethods	soot_jimple_parser_Walker;
	_jc_soot_jimple_parser_BodyExtractorWalker$vmethods	soot_jimple_parser_BodyExtractorWalker;
};

// Vtype
struct _jc_soot_jimple_parser_BodyExtractorWalker$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_BodyExtractorWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_refs {
	struct _jc_object	*methodToParsedBodyMap;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_BodyExtractorWalker$refs {
    _jc_soot_jimple_parser_BodyExtractorWalker$sub_refs	soot_jimple_parser_BodyExtractorWalker;
    _jc_soot_jimple_parser_Walker$sub_refs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_refs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_refs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_BodyExtractorWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_nonrefs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_nonrefs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_Walker$sub_nonrefs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs	soot_jimple_parser_BodyExtractorWalker;
};

// Object instance structure
struct _jc_soot_jimple_parser_BodyExtractorWalker$object {
	_jc_soot_jimple_parser_BodyExtractorWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_BodyExtractorWalker$vtype	*vtype;
	_jc_soot_jimple_parser_BodyExtractorWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_BodyExtractorWalker$vtype _jc_soot_jimple_parser_BodyExtractorWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_BodyExtractorWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_BodyExtractorWalker$class_object;

#endif	/* _JC_soot_jimple_parser_BodyExtractorWalker_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/BodyExtractorWalker.h <==
// public class soot.jimple.parser.BodyExtractorWalker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 72cded5f00a3b1f0 soot_jimple_parser_BodyExtractorWalker
// @dep_class b8af2571138d5c8f soot_jimple_parser_Walker
// @dep_class b43a9165b67db951 soot_jimple_parser_analysis_AnalysisAdapter
// @dep_class 49cf7a14fc836e70 soot_jimple_parser_analysis_DepthFirstAdapter

// header file dependencies
// @dep_header soot_jimple_parser_Walker

#include "soot/jimple/parser/Walker.h"

#ifndef _JC_soot_jimple_parser_BodyExtractorWalker_H_
#define _JC_soot_jimple_parser_BodyExtractorWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootResolver$object;
struct _jc_soot_jimple_parser_node_AFieldMember$object;
struct _jc_soot_jimple_parser_node_AFile$object;
struct _jc_soot_jimple_parser_node_AMethodMember$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_refs	_jc_soot_jimple_parser_BodyExtractorWalker$sub_refs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs	_jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$refs	_jc_soot_jimple_parser_BodyExtractorWalker$refs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$nonrefs	_jc_soot_jimple_parser_BodyExtractorWalker$nonrefs;
typedef struct _jc_soot_jimple_parser_BodyExtractorWalker$object	_jc_soot_jimple_parser_BodyExtractorWalker$object;

typedef const struct _jc_soot_jimple_parser_BodyExtractorWalker$vmethods	_jc_soot_jimple_parser_BodyExtractorWalker$vmethods;
typedef const struct _jc_soot_jimple_parser_BodyExtractorWalker$vtable	_jc_soot_jimple_parser_BodyExtractorWalker$vtable;
typedef const struct _jc_soot_jimple_parser_BodyExtractorWalker$vtype	_jc_soot_jimple_parser_BodyExtractorWalker$vtype;

// Constructors
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$_init$9a25abd79642d432(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_SootClass$object *, struct _jc_soot_SootResolver$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$caseAFile$b6916389b57c776a(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$outAFieldMember$280c058d1a940a2c(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFieldMember$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$outAFile$453969294ea1f0d8(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_BodyExtractorWalker$method$outAMethodMember$0fbbcd28a24c2ab7(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$caseAFile$b6916389b57c776a;
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$outAFieldMember$280c058d1a940a2c;
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$outAFile$453969294ea1f0d8;
extern _jc_method _jc_soot_jimple_parser_BodyExtractorWalker$method_info$outAMethodMember$0fbbcd28a24c2ab7;

// Virtual methods structure
struct _jc_soot_jimple_parser_BodyExtractorWalker$vmethods {
	void	(*caseAFile$b6916389b57c776a)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
	void	(*outAFieldMember$280c058d1a940a2c)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFieldMember$object *) _JC_JCNI_ATTR;
	void	(*outAFile$453969294ea1f0d8)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
	void	(*outAMethodMember$0fbbcd28a24c2ab7)(_jc_env *, struct _jc_soot_jimple_parser_BodyExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_BodyExtractorWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_analysis_AnalysisAdapter$vmethods	soot_jimple_parser_analysis_AnalysisAdapter;
	_jc_soot_jimple_parser_analysis_DepthFirstAdapter$vmethods	soot_jimple_parser_analysis_DepthFirstAdapter;
	_jc_soot_jimple_parser_Walker$vmethods	soot_jimple_parser_Walker;
	_jc_soot_jimple_parser_BodyExtractorWalker$vmethods	soot_jimple_parser_BodyExtractorWalker;
};

// Vtype
struct _jc_soot_jimple_parser_BodyExtractorWalker$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_BodyExtractorWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_refs {
	struct _jc_object	*methodToParsedBodyMap;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_BodyExtractorWalker$refs {
    _jc_soot_jimple_parser_BodyExtractorWalker$sub_refs	soot_jimple_parser_BodyExtractorWalker;
    _jc_soot_jimple_parser_Walker$sub_refs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_refs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_refs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_BodyExtractorWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_nonrefs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_nonrefs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_Walker$sub_nonrefs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_BodyExtractorWalker$sub_nonrefs	soot_jimple_parser_BodyExtractorWalker;
};

// Object instance structure
struct _jc_soot_jimple_parser_BodyExtractorWalker$object {
	_jc_soot_jimple_parser_BodyExtractorWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_BodyExtractorWalker$vtype	*vtype;
	_jc_soot_jimple_parser_BodyExtractorWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_BodyExtractorWalker$vtype _jc_soot_jimple_parser_BodyExtractorWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_BodyExtractorWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_BodyExtractorWalker$class_object;

#endif	/* _JC_soot_jimple_parser_BodyExtractorWalker_H_ */
